
# Store encrypted protobuffed data in the cookies
This package is a Proof of Concept for storing encrypted protobuffed data in the cookies

# Installation

  pip install protocookie

# Running

Run:

  python3 -m protocookie.server

After that open http://localhost:5000 in your browser

# Dependencies

All the dependencies should be managed by pip, but here is a list, just in case:

python >= 3
protobuf
flask
cryptography

